<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Gerioù ha strolladoù ger',
	'mots_slogan' => 'Merañ gerioù hag strolladoù ger e  SPIP',
];
